## Markdown Edit Sandbox

This is a simple markdown editor that allows you to write markdown on the left and see the rendered HTML on the right.

##### Markdown Examples

Here are a number of Markdown examples that show how to use various features of the default Markdown (python) API and the extra extensions developed for this site.

{% include 'docs/markdown_examples/examples_form.html' %}

##### Edit and preview

Here you can edit the markdown on the left and see the rendered HTML on the right. Choose one of the examples above to get started.

Here are some markdown references that might help:

- Markdown guide
- Python Markdown
- GitHub's Markdown Guidance
- Mermaid Examples (official site)
- Mermaid Examples (rudolfolah/mermaid-diagram-examples)

# Markdown Editor start typing here, or choose one of the examples from the options above